@@ -2,9 +2,9 @@
 # Copyright (c) 2011-2013 Raphaël Barrois
 # This code is distributed under the two-clause BSD License.
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 __author__ = 'Raphaël Barrois <raphael.barrois+fslib@polytechnique.org>'
 
 
-from .base import FileSystem, OSFS
+from .base import FileSystem, OSFS, ROOT
 from .exceptions import FSError
